@@ -8,14 +8,12 @@
 #include <stdlib.h>
 #include <fcntl.h>
 #include <linux/kd.h>
-#include <sys/ioctl.h>
+#include "kdmapop.h"
+#include "getfd.h"
 #include "nls.h"
 
-extern int getfd(void);
-
 int
 main(int argc, char *argv[]) {
-	struct unimapinit advice;
 	int fd;
 
 	setlocale(LC_ALL, "");
@@ -24,12 +22,5 @@ main(int argc, char *argv[]) {
 
 	fd = getfd();
 
-	advice.advised_hashsize = 0;
-	advice.advised_hashstep = 0;
-	advice.advised_hashlevel = 0;
-
-	if(ioctl(fd, PIO_UNIMAPCLR, &advice)) {
-		perror("PIO_UNIMAPCLR");
-		exit(1);
-	}
+	return loadunimap (fd, NULL, NULL);
 }
