@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -51,6 +52,10 @@ int getfd() {
     if (fd >= 0)
       return fd;
 
+    fd = open_a_console("/dev/vc/0");
+    if (fd >= 0)
+      return fd;
+
     fd = open_a_console("/dev/console");
     if (fd >= 0)
       return fd;
