@@ -1123,6 +1123,7 @@ static sym iso_8859_9_syms[] = { /* latin-5 */
 #include "koi8.syms.h"
 #include "cp1250.syms.h"
 #include "ethiopic.syms.h"
+#include "sami.syms.h"
 
 static sym iso_8859_15_syms[] = {
 	/* latin-1 with 8 changes */
@@ -1601,12 +1602,15 @@ struct cs {
     { "iso-8859-7",	iso_8859_7_syms, 160 },
     { "iso-8859-8",	iso_8859_8_syms, 160 },
     { "iso-8859-9",	iso_8859_9_syms, 208 },
+    { "iso-8859-10",	latin6_syms, 160 },
     { "iso-8859-15",	iso_8859_15_syms, 160 },
     { "mazovia",	mazovia_syms, 128 },
     { "cp-1250",	cp1250_syms, 128 },
     { "koi8-r",		koi8_syms, 128 },
     { "koi8-u",		koi8_syms, 128 },
     { "iso-10646-18",	iso_10646_18_syms, 159 },	/* ethiopic */
+    { "iso-ir-197",	iso_ir_197_syms, 160 },		/* sami */
+    { "iso-ir-209",	iso_ir_209_syms, 160 },		/* sami */
 };
 
 /* Functions for both dumpkeys and loadkeys. */
